variable "aws_shared_cred_file" {}
variable "aws_profile" {
  default = "default"
}
variable "aws_region" {
  # test tier
  default = "us-east-1"
}

variable "vpc_tags" {
  type    = map(string)
  default = {
    Name = "test-tier"
    tier = "test"
  }
}

# needs at least two subnets
variable "private_subnets_filter" {
  type    = map(string)
  default = {
    Name = "test-private-*"
  }
}

variable "security_group" {
  type    = map(string)
  default = {
    tier = "test"
    Name = "internal"
  }
}

# see git tagging in .gitlab-ci.yml for image name.
variable "image_name" {
  description = "Secure Agent image name publish by .gitlab-ci.yml."
}

variable "container_name" {
  description = "Container name for Secure Agent image."
  default = "iics-secure-agent-test"
}
variable "container_network_mode" {
  default = "awsvpc"
}
variable "container_app_port" {
  type    = list(string)
  default = [
    7080,
    7443,
    5432]
}

# note that as per our licesning model each
# container would be an extran instance
variable "container_count" {
  default = 1
}

# https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-cpu-memory-error.html
# see Secure Agent resource requirements for these numbers.
variable "fargate_cpu" {
  # 1 vCPU = 1024 CPU units
  default = "4096"
}
variable "fargate_memory" {
  # in MiB
  default = "8192"
}

# ecs
variable "ecs_cluster_name" {
  default = "iics-agent-cluster"
}

variable "ecs_cluster_tags" {
  type    = map(string)
  default = {
    Name = "iics-agent-cluster"
    tier = "test"
  }
}

variable "ecs_task_name" {
  default = "iics-agent-task"
}

variable "ecs_service_name" {
  default = "iics-agent-service"
}

variable "informatica_username" {}
variable "informatica_password" {}